@@ -8,6 +8,7 @@ import urllib
 import logging
 import io
 
+
 logger = logging.Logger(__name__)
 
 def load_derby_game_from_json_file(filepath) -> DerbyGame:
@@ -73,4 +74,16 @@ def load_game_json_from_server(
         f"http://{server}:{port}/SaveJSON/scoreboard-0-secs-ago.json") as response:
         game_json = json.load(response,
             encoding=response.headers.get_content_charset())
-    return game_json
\ No newline at end of file
+    return game_json
+
+
+# Websockets interface
+
+WS_REGISTER_STR = json.dumps({
+  "action": "Register",
+  "paths": [
+      "ScoreBoard.Version(release)",
+      "ScoreBoard.CurrentGame",
+  ]
+})
+
